==> nextcloud-27.1.3.tgz: nextcloud/apps/serverinfo/l10n/pt_PT.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informação do CPU indisponível",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitorização",
    "Monitoring app with useful server information" : "Aplicação de monitorização com informação útil do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Disponibiliza informação útil do servidor como a carga do CPU, utilização da RAM, utilização do disco, número de utilizadores, etc.",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memória",
    "Disk" : "Disco",
    "Size:" : "Tamanho:",
    "Files:" : "Ficheiros:",
    "Storages:" : "Armazenamentos:",
    "Free Space:" : "Espaço livre:",
    "Network" : "Rede",
    "Active users" : "Utilizadores activos",
    "Total users:" : "Total de utilizadores:",
    "Shares" : "Partilhas",
    "Users:" : "Utilizadores:",
    "PHP" : "PHP",
    "Version:" : "Versão:",
    "Upload max size:" : "Tamanho máximo de carregamento:",
    "Database" : "Base de dados",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ferramenta externa de monitorização",
    "You can connect an external monitoring tool by using this end point:" : "Pode ligar uma ferramenta de monitorização externa ao usar \"endpoint\":",
    "Copy" : "Copiar",
    "You will get a notification once one of your disks is nearly full." : "Receberá uma notificação logo que um dos seus discos esteja perto de estar cheio."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.14.tgz: nextcloud/apps/serverinfo/l10n/pt_PT.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informação do CPU indisponível",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitorização",
    "Monitoring app with useful server information" : "Aplicação de monitorização com informação útil do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Disponibiliza informação útil do servidor como a carga do CPU, utilização da RAM, utilização do disco, número de utilizadores, etc.",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memória",
    "Disk" : "Disco",
    "Size:" : "Tamanho:",
    "Files:" : "Ficheiros:",
    "Storages:" : "Armazenamentos:",
    "Free Space:" : "Espaço livre:",
    "Network" : "Rede",
    "Active users" : "Utilizadores activos",
    "Last hour" : "Ultima hora",
    "Shares" : "Partilhas",
    "Users:" : "Utilizadores:",
    "PHP" : "PHP",
    "Version:" : "Versão:",
    "Upload max size:" : "Tamanho máximo de carregamento:",
    "Database" : "Base de dados",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ferramenta externa de monitorização",
    "Copy" : "Copiar",
    "Total users:" : "Total de utilizadores:"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
